<template>
	<div class="system-edit-user-container">
		<el-dialog :title="titles" v-model="isShowDialog" width="50%" draggable :fullscreen="full"
				   destroy-on-close @close="closeDialog(ruleFormRef)">
			<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
			<el-form ref="ruleFormRef" :model="ruleForm" :rules="rules" size="default" label-width="140px">
				<el-row :gutter="35">
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="事故名称" prop="accidentName">
							<el-input v-model="ruleForm.accidentName" :disabled="disabled" placeholder="请填写事故名称"></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="事故部门" placeholder="请选择" prop="accidentDepartmentId">
							<el-tree-select
								v-model="ruleForm.accidentDepartmentId"
								:disabled="disabled"
								:props="propse"
								:data="newTreeList"
								class="w100"
								placeholder="请选择"
							/>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="发生地点" prop="occurrencePlace">
							<el-input v-model="ruleForm.occurrencePlace" :disabled="disabled" placeholder="请填写发生地点"></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="发生时间" prop="occurrenceTime">
							<!--<el-input v-model="ruleForm.occurrenceTime" :disabled="disabled" placeholder="请填写发生时间"></el-input>-->
							<el-date-picker
								:disabled="disabled"
								v-model="ruleForm.occurrenceTime"
								value-format="YYYY-MM-DD HH:mm:ss"
								type="datetime"
								class="w100"
								placeholder="选择日期时间"
							/>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="事故原因" prop="accidentCause">
							<el-select v-model="ruleForm.accidentCause" :disabled="disabled" class="w100" placeholder="请选择">
								<el-option label="人的不安全行为" value="1"></el-option>
								<el-option label="物的不安全状态" value="2"></el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="是否有伤亡" prop="casualties">
							<el-radio-group v-model="ruleForm.casualties" :disabled="disabled" @change="typeChang">
								<el-radio :label="true">是</el-radio>
								<el-radio :label="false">否</el-radio>
							</el-radio-group>
							<el-button v-if="ruleForm.casualties" type="primary" style="margin-left: 20px"
									   :icon="Edit" @click="openDai" round plain />
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="事故简要经过" prop="accidentBriefProcess">
							<el-input
								v-model="ruleForm.accidentBriefProcess"
								:disabled="disabled"
								type="textarea"
								placeholder="请填写事故简要经过"
								maxlength="150"
							></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="事故原因初步分析" prop="accidentCausesPreliminaryAnalysis">
							<el-input
								v-model="ruleForm.accidentCausesPreliminaryAnalysis"
								:disabled="disabled"
								type="textarea"
								placeholder="请填写事故原因初步分析"
								maxlength="150"
							></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
						<el-form-item label="应急防范措施" prop="emergencyPrecautions">
							<el-input
								v-model="ruleForm.emergencyPrecautions"
								:disabled="disabled"
								type="textarea"
								placeholder="请填写应急防范措施"
								maxlength="150"
							></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
						<el-form-item label="事故照片" prop="fileList">
							<!--<el-input v-model="ruleForm.fileList" :disabled="disabled"-->
							<!--type="textarea" placeholder="请填写应急防范措施" maxlength="150"></el-input>-->
							<uploaderImg :fileList="fileList" :disabled="disabled"
										 :systemName="'INCIDENT_MANAGE'" @successUploader="successUploader"></uploaderImg>
						</el-form-item>
					</el-col>
				</el-row>
			</el-form>
			<template #footer>
				<span class="dialog-footer">
					<el-button @click="resetForm(ruleFormRef)" size="default">关闭</el-button>
					<el-button size="default" v-if="disabled == true ? false : true" type="primary"
                               @click="submitForm(titles, ruleFormRef)">确定</el-button>
				</span>
			</template>
		</el-dialog>
		<NumberOfCasualties ref="ShowUser"></NumberOfCasualties>
		<CheckTemplate ref="Shows" />
		<userSelections ref="userRef" />
		<RegionsDialog ref="openRef" />
	</div>
</template>

<script lang="ts">
import { reactive, ref, defineComponent, defineEmits, onMounted } from 'vue';

import type { UploadUserFile, FormInstance, FormRules } from 'element-plus';
import { ElMessage } from 'element-plus';
import { Search, FullScreen, Edit } from '@element-plus/icons-vue';
import NumberOfCasualties from '/@/views/accidentManagementSystem/accidentExpress/component/numberOfCasualties.vue';
import UserSelections from '/@/components/userSelections/index.vue';
import CheckTemplate from '/@/components/checkTemplate/index.vue';
import uploaderImg from '/@/components/uploaderImg/index.vue';
import RegionsDialog from '/@/components/regionsDialog/index.vue';
import { accidentManagementSystemApi } from '/@/api/accidentManagementSystem';
import { goalManagementApi } from '/@/api/goalManagement';
export default defineComponent({
	name: 'openAdd',
	components: {
		CheckTemplate,
		UserSelections,
		RegionsDialog,
		NumberOfCasualties,
		uploaderImg,
	},
	setup(props, { emit }) {
		const isShowDialog = ref(false);

		const ruleFormRef = ref<FormInstance>();
		//定义表单
		const ruleForm = ref({
			emergencyPrecautions: '',
			accidentCausesPreliminaryAnalysis: '',
			accidentBriefProcess: '',
			casualties: '',
			accidentCause: '',
			occurrenceTime: '',
			occurrencePlace: '',
			accidentDepartmentId: '',
			accidentName: '',
			fileList: [],
			id: '',
		});
		const titles = ref();
		const disabled = ref();
		// 打开弹窗
		const openDialog = async (title: string, id: number, type: boolean) => {
			isShowDialog.value = true;
			titles.value = title;
			disabled.value = type;
			if (title == '查看事故快报' || title == '修改事故快报') {
				accidentManagementSystemApi()
					.accidentScarh(id)
					.then((res) => {
						if (res.data.code == 200) {
							ruleForm.value = res.data.data;
							fileList.value = (res.data.data.fileList?res.data.data.fileList:[])
							initFileListData()
						}
					});
			}
		};
		const initFileListData = async () => {
			for(var a = 0;a<fileList.value.length;a++){
				await goalManagementApi()
						.searchFile(fileList.value[a].fileName)
						.then((res) => {
							fileList.value[a].url = res.data
						})
			}
		}
		//日期选择器
		const value1 = ref('');
		// 上传附件
		const fileList = ref([]);
		// 上传成功组装数据
		const successUploader = (list) =>{
			fileList.value = list
			const formFileList = []
			for(var a = 0;a<fileList.value.length;a++){
				formFileList.push(
					{
						fileName:fileList.value[a].fileName,
						fileUrl:''
					}
				)
			}
			ruleForm.value.fileList = formFileList
		}
		// 可选择树
		const treeSelect = ref();

		//定义树形下拉框
		const responsibleDepartment = ref();
		const data = [];
		//el-tree-select回显
		const propse = {
			label: 'depName',
			children: 'children',
		};
		const newTreeList = [];
		//得到部门树
		const department = async () => {
			await goalManagementApi()
				.getTreedepartment()
				.then((res) => {
					if (res.data.code == 200) {
						data.value = res.data.data;
						getTreeList(res.data.data, newTreeList);
					} else {
						ElMessage.error(res.data.msg);
					}
				});
		};
		// 递归树状数据且修改字段名
		const getTreeList = (treeList, newTreeList) => {
			treeList.map((c) => {
				let tempData = {
					depName: c.depName,
					value: c.depId,
					children: [],
				};
				if (c.children && c.children.length > 0) {
					tempData.children = [];
					getTreeList(c.children, tempData.children);
				}
				newTreeList.push(tempData);
			});
		};
		onMounted(() => {
			department();
		});
		// 必填项提示
		const rules = reactive<FormRules>({
			accidentName: [
				{
					required: true,
					message: '事故名称不能为空',
					trigger: 'change',
				},
			],
			accidentDepartmentId: [
				{
					required: true,
					message: '事故部门不能为空',
					trigger: 'change',
				},
			],
			occurrencePlace: [
				{
					required: true,
					message: '发生地点不能为空',
					trigger: 'change',
				},
			],
			occurrenceTime: [{ type: 'date', required: true, message: '发生时间不能为空', trigger: 'blur' }],
			accidentCause: [
				{
					required: true,
					message: '事故原因不能为空',
					trigger: 'change',
				},
			],
			casualties: [
				{
					required: true,
					message: '是否有伤亡不能为空',
					trigger: 'change',
				},
			],
			accidentBriefProcess: [
				{
					required: true,
					message: '事故简要经过不能为空',
					trigger: 'change',
				},
			],
			accidentCausesPreliminaryAnalysis: [
				{
					required: true,
					message: '事故原因初步分析不能为空',
					trigger: 'change',
				},
			],
			emergencyPrecautions: [
				{
					required: true,
					message: '应急防范措施不能为空',
					trigger: 'change',
				},
			],
		});
		// 子传父
		// const emit=defineEmits(['myAdd'])
		// 表单提交验证必填项
		const submitForm = async (title: string, formEl: FormInstance | undefined) => {
			if(!ruleForm.value.fileList){
				ruleForm.value.fileList = []
			}
			if (title == '新建事故快报') {
				if (!formEl) return;
				await formEl.validate((valid, fields) => {
					if (valid) {
						isShowDialog.value = false;
						ruleForm.value.id = null;
						accidentManagementSystemApi()
							.accidentAdd(ruleForm.value)
							.then((res) => {
								if (res.data.code == 200) {
									ElMessage({
										showClose: true,
										message: res.data.msg,
										type: 'success',
									});
									emit('myAdd', true);
								} else {
									ElMessage({
										showClose: true,
										message: res.data.msg,
										type: 'error',
									});
									emit('myAdd', true);
								}
								formEl.resetFields();
							});
					} else {
						console.log('error submit!', fields);
					}
				});
			} else if (title == '修改事故快报') {
				if (!formEl) return;
				await formEl.validate((valid, fields) => {
					if (valid) {
						isShowDialog.value = false;
						accidentManagementSystemApi()
							.accidentView(ruleForm.value)
							.then((res) => {
								if (res.data.code == 200) {
									ElMessage({
										showClose: true,
										message: '修改成功',
										type: 'success',
									});
									emit('myAdd', true);
								} else {
									ElMessage({
										showClose: true,
										message: res.data.msg,
										type: 'error',
									});
									emit('myAdd', true);
								}
								formEl.resetFields();
							});
					} else {
						console.log('error submit!', fields);
					}
				});
				formEl.resetFields();
			}
			ruleForm.value = {
				accidentExpressId: '',
				emergencyPrecautions: '',
				accidentCausesPreliminaryAnalysis: '',
				accidentBriefProcess: '',
				casualties: '',
				accidentCause: '',
				occurrenceTime: '',
				occurrencePlace: '',
				accidentDepartmentId: '',
				accidentName: '',
				fileList: [],
			};
		};
		const resetForm = (formEl: FormInstance | undefined) => {
			isShowDialog.value = false;
			if (!formEl) return;
			formEl.resetFields();
		};
		const closeDialog = (formEl: FormInstance | undefined) => {
			formEl.resetFields();
			fileList.value = []
			console.log(ruleForm);
			isShowDialog.value = false;
		};
		// 是否有伤亡弹窗
		const typeChang = () => {
			console.log('tag', ruleForm);
		};
		const ShowUser = ref();
		const openDai = () => {
            if(ruleForm.value.id==null||ruleForm.value.id==''){
                ElMessage({
                    showClose: true,
                    message: '请先添加事故快报',
                    type: 'info',
                });
            }else {
                ShowUser.value.openDialog(ruleForm.value.id, disabled.value);
            }

		};
		// 应急队伍弹窗
		const Shows = ref();
		const daiInpt = () => {
			Shows.value.openDailog();
		};
		// 选择区域弹窗
		const openRef = ref();
		const regionsDialog = () => {
			openRef.value.openDailog();
		};
		// 打开用户选择弹窗
		const userRef = ref();
		const openUser = () => {
			userRef.value.openDialog();
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		return {
			ShowUser,
			typeChang,
			openDialog,
			isShowDialog,
			fileList,
			responsibleDepartment,
			data,
			Search,
			Edit,
			ruleForm,
			value1,
			treeSelect,
			daiInpt,
			Shows,
			ruleFormRef,
			submitForm,
			resetForm,
			rules,
			openUser,
			userRef,
			regionsDialog,
			openDai,
			openRef,
			toggleFullscreen,
			FullScreen,
			full,
			titles,
			disabled,
			emit,
			propse,
			department,
			getTreeList,
			newTreeList,
			closeDialog,
			successUploader
		};
	},
});
</script>
<style scoped lang="scss">
.textarea {
	height: 168px !important;
}
.textarea ::v-deep .el-textarea__inner {
	height: 168px !important;
}
::v-deep .el-table__cell {
	font-weight: 400;
}
.el-divider--horizontal {
	height: 0;
	margin: 0;
	border-top: transparent;
}
.el-select {
	width: 100%;
}
</style>
